/***************************************************************************
                          job_disconnectfromdatabase.h  -  description
                             -------------------
    begin                : Fri May 4 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_DISCONNECTFROMDATABASE_H
#define JOB_DISCONNECTFROMDATABASE_H

#include "prokyon.h"

#include "jobbase.h"

class Job_DisconnectFromDatabase : public JobBase  {
public:
    Job_DisconnectFromDatabase();

    int type() {
        return JOB_DISCONNECT_FROM_DATABASE;
    }

    void run();

    ~Job_DisconnectFromDatabase();
};

#endif
